@@ -22,6 +22,8 @@
 
 /* this file is only built if GNOME support is enabled */
 
+#undef GTK_DISABLE_DEPRECATED
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -93,7 +95,7 @@ static const gnomeuiinfo_map_t gnome_uiinfo_mapping[] = {
     { "UNDO_ITEM", GNOMEUIINFO_MENU_UNDO_ITEM(NULL, NULL) },
     { "UNDO_MOVE_ITEM", GNOMEUIINFO_MENU_UNDO_MOVE_ITEM(NULL, NULL) },
     { "VIEW_TREE", GNOMEUIINFO_MENU_VIEW_TREE(tmptree) },
-    { "WINDOWS_TREE", GNOMEUIINFO_MENU_WINDOWS_TREE(tmptree) },
+    { "WINDOWS_TREE", GNOMEUIINFO_MENU_WINDOWS_TREE(tmptree) }
 };
 
 static int
