@@ -28,19 +28,18 @@
 
 #include <unistd.h>
 #include <sys/types.h>
-#include <gtk/gtkobject.h>
-#include <gtk/gtkdialog.h>
+#include <gtk/gtk.h>
 
 #include <libgnome/gnome-program.h>
 
 G_BEGIN_DECLS
 
 #define GNOME_TYPE_CLIENT            (gnome_client_get_type ())
-#define GNOME_CLIENT(obj)            (GTK_CHECK_CAST ((obj), GNOME_TYPE_CLIENT, GnomeClient))
-#define GNOME_CLIENT_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), GNOME_TYPE_CLIENT, GnomeClientClass))
-#define GNOME_IS_CLIENT(obj)         (GTK_CHECK_TYPE ((obj), GNOME_TYPE_CLIENT))
-#define GNOME_IS_CLIENT_CLASS(klass) (GTK_CHECK_CLASS_TYPE (((klass), GNOME_TYPE_CLIENT))
-#define GNOME_CLIENT_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), GNOME_TYPE_CLIENT, GnomeClientClass))
+#define GNOME_CLIENT(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_TYPE_CLIENT, GnomeClient))
+#define GNOME_CLIENT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_TYPE_CLIENT, GnomeClientClass))
+#define GNOME_IS_CLIENT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_TYPE_CLIENT))
+#define GNOME_IS_CLIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE (((klass), GNOME_TYPE_CLIENT)))
+#define GNOME_CLIENT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_TYPE_CLIENT, GnomeClientClass))
 
 #define GNOME_CLIENT_CONNECTED(obj) (GNOME_CLIENT (obj)->smc_conn)
 
@@ -351,14 +350,14 @@ void         gnome_client_save_any_dialog       (GnomeClient *client,
 					         GtkDialog   *dialog);
 
 /* The following function may be called during a "save_youself" handler
-   when an error has occured during the save. The session manager decides 
+   when an error has occurred during the save. The session manager decides 
    when the dialog is shown and it will not be shown when the interact_style
    == GNOME_INTERACT_NONE.  A "Cancel Logout" button will be added 
    during a shutdown. */
 void         gnome_client_save_error_dialog      (GnomeClient *client,
 					          GtkDialog   *dialog);
 
-/* Request the session managaer to emit the "save_yourself" signal for 
+/* Request the session manager to emit the "save_yourself" signal for 
    a second time after all the clients in the session have ceased 
    interacting with the user and entered an idle state. This might be 
    useful if your app manages other apps and requires that they are in 
@@ -410,7 +409,7 @@ GnomeClient *gnome_client_new_without_connection (void);
 
 /* Try to connect to a session manager.  If the client was created
    with a valid session management client id, we will try to connect
-   to the manager with this old id.  If the connection was successfull,
+   to the manager with this old id.  If the connection was successful,
    the "connect" signal will be emitted, after some default properties
    have been sent to the session manager.  */
 void         gnome_client_connect                (GnomeClient *client);
@@ -426,7 +425,7 @@ void         gnome_client_set_id                 (GnomeClient *client,
 
 /* Get the client id of a session management client object.  If this
    object has never been connected to a session manager and a client
-   id hasn't been set, this function return 'NULL'.  */
+   id hasn't been set, this function returns 'NULL'.  */
 const gchar*       gnome_client_get_id                 (GnomeClient *client);
 
 /* Get the client id from the last session.  If this client was not
@@ -457,7 +456,7 @@ void         gnome_client_request_interaction_interp (GnomeClient *client,
 						      GnomeDialogType dialog_type,
 						      GtkCallbackMarshal function,
 						      gpointer data,
-						      GtkDestroyNotify destroy);
+						      GDestroyNotify destroy);
 
 /* 'gnome_interaction_key_return' is used to tell gnome, that you are
    finished with interaction */
