@@ -28,17 +28,15 @@
 #include <config.h>
 #include <math.h>
 #include <libgnome/gnome-macros.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <gdk/gdkrgb.h>
+#include <gdk/gdk.h>
 #include <libart_lgpl/art_rgb_affine.h>
 #include <libart_lgpl/art_rgb_rgba_affine.h>
 #include <string.h>
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include "gnome-icon-item.h"
 #include "gnome-marshal.h"
@@ -96,7 +94,7 @@ enum {
 static guint iti_signals [LAST_SIGNAL] = { 0 };
 
 GNOME_CLASS_BOILERPLATE (GnomeIconTextItem, gnome_icon_text_item,
-			 GnomeCanvasItem, GNOME_TYPE_CANVAS_ITEM);
+			 GnomeCanvasItem, GNOME_TYPE_CANVAS_ITEM)
 
 static void
 send_focus_event (GnomeIconTextItem *iti, gboolean in)
