@@ -32,11 +32,10 @@
  *   Miguel de Icaza <miguel@nuclecu.unam.mx>
  */
 
-#ifndef GNOME_DISABLE_DEPRECATED
-
 #ifndef _GNOME_ICON_LIST_H_
 #define _GNOME_ICON_LIST_H_
 
+#ifndef GNOME_DISABLE_DEPRECATED
 
 #include <libgnomecanvas/gnome-canvas.h>
 #include <libgnomecanvas/gnome-canvas-rich-text.h>
@@ -47,11 +46,11 @@
 G_BEGIN_DECLS
 
 #define GNOME_TYPE_ICON_LIST            (gnome_icon_list_get_type ())
-#define GNOME_ICON_LIST(obj)            (GTK_CHECK_CAST ((obj), GNOME_TYPE_ICON_LIST, GnomeIconList))
-#define GNOME_ICON_LIST_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), GNOME_TYPE_ICON_LIST, GnomeIconListClass))
-#define GNOME_IS_ICON_LIST(obj)         (GTK_CHECK_TYPE ((obj), GNOME_TYPE_ICON_LIST))
-#define GNOME_IS_ICON_LIST_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GNOME_TYPE_ICON_LIST))
-#define GNOME_ICON_LIST_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), GNOME_TYPE_ICON_LIST, GnomeIconListClass))
+#define GNOME_ICON_LIST(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_TYPE_ICON_LIST, GnomeIconList))
+#define GNOME_ICON_LIST_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_TYPE_ICON_LIST, GnomeIconListClass))
+#define GNOME_IS_ICON_LIST(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_TYPE_ICON_LIST))
+#define GNOME_IS_ICON_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_TYPE_ICON_LIST))
+#define GNOME_ICON_LIST_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_TYPE_ICON_LIST, GnomeIconListClass))
 
 typedef struct _GnomeIconList        GnomeIconList;
 typedef struct _GnomeIconListPrivate GnomeIconListPrivate;
@@ -213,10 +212,9 @@ GnomeIconTextItem *gnome_icon_list_get_icon_text_item (GnomeIconList *gil,
 GnomeCanvasPixbuf *gnome_icon_list_get_icon_pixbuf_item (GnomeIconList *gil,
 							 int idx);
 
-
-
 G_END_DECLS
 
+#endif /* GNOME_DISABLE_DEPRECATED */
+
 #endif /* _GNOME_ICON_LIST_H_ */
 
-#endif /* GNOME_DISABLE_DEPRECATED */
