@@ -371,7 +371,7 @@ gnome_thumbnail_factory_lookup (GnomeThumbnailFactory *factory,
     return path;
 
   g_free (path);
-  return FALSE;
+  return NULL;
 }
 
 /**
@@ -442,7 +442,7 @@ mimetype_supported_by_gdk_pixbuf (const char *mime_type)
 	if (!formats_hash) {
 		GSList *formats, *list;
 		
-		formats_hash = g_hash_table_new (g_str_hash, g_str_equal);
+		formats_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
 		formats = gdk_pixbuf_get_formats ();
 		list = formats;
@@ -629,9 +629,8 @@ gnome_thumbnail_factory_generate_thumbnail (GnomeThumbnailFactory *factory,
   if (script)
     {
       int fd;
-      GError *error = NULL;
 
-      fd = g_file_open_tmp (".gnome_thumbnail.XXXXXX", &tmpname, &error);
+      fd = g_file_open_tmp (".gnome_thumbnail.XXXXXX", &tmpname, NULL);
 
       if (fd != -1)
 	{
@@ -648,8 +647,8 @@ gnome_thumbnail_factory_generate_thumbnail (GnomeThumbnailFactory *factory,
 
 	  g_free (expanded_script);
 	  g_unlink(tmpname);
+	  g_free (tmpname);
 	}
-      g_free (tmpname);
     }
 
   /* Fall back to gdk-pixbuf */
