@@ -1,7 +1,5 @@
 
-/* Generated data (by glib-mkenums) */
 
-#undef GTK_DISABLE_DEPRECATED
 
 #include "libgnomeui.h"
 
@@ -455,5 +453,5 @@ gnome_preferences_type_get_type (void)
 }
 
 
-/* Generated data ends here */
+
 
