@@ -16,7 +16,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 #ifndef __PROP_EDITOR_H__
 #define __PROP_EDITOR_H__
